@@ -23,7 +23,7 @@ impl Message {
 
 pub type MessageFieldList = &'static [&'static MessageField];
 
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone)]
 pub struct MessageField {
     pub message: &'static Message,
     pub snakecase_name: &'static str,
@@ -31,6 +31,14 @@ pub struct MessageField {
     pub comment: &'static [&'static str],
 }
 
+impl PartialEq for MessageField {
+    fn eq(&self, other: &Self) -> bool {
+        self.snakecase_name == other.snakecase_name
+            && self.field_type == other.field_type
+            && self.comment == other.comment
+    }
+}
+
 impl MessageField {
     pub fn render_comment(&self, prefix: &str, offset: usize) -> String {
         crate::comment::Comment::new(self.comment, prefix).to_string(offset)
